@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def mom(df, price, col, n):
+def mom(df, price="close", col="mom", n):
     """
     The Momentum indicator is a speed of movement indicator designed to identify the speed (or strength) of price movement. 
     The momentum indicator compares the most recent closing price to a previous closing price (can be the closing price of any time frame). 
