@@ -2,7 +2,7 @@ import numpy as np
 import pandas as pd
 
 
-def aroon(df, high, low, aroon, n):
+def aroon(df, high="high", low="low", col="aroon", n):
     """
     Aroon is an indicator system that determines whether a stock is trending or
     not and how strong the trend is. The Aroon indicators measure the number of
@@ -17,7 +17,7 @@ def aroon(df, high, low, aroon, n):
         df (pd.DataFrame): DataFrame which contain the asset information.
         high (string): the column name for the period highest price  of the asset.
         low (string): the column name for the period lowest price of the asset.
-        aroon (string): the column name for the results of aroon up and aroon down.
+        col (string): the column name for the results of price up and price down.
         n (int): the total number of periods.
 
     Returns:
@@ -25,12 +25,12 @@ def aroon(df, high, low, aroon, n):
 
     """
 
-    df[aroon + "_up"] = (
+    df[col + "_up"] = (
         df[high]
         .rolling(n)
         .apply(lambda x: float(np.argmax(x) + 1) / n * 100, raw=True)
     )
-    df[aroon + "_dn"] = (
+    df[col + "_dn"] = (
         df[low]
         .rolling(n)
         .apply(lambda x: float(np.argmin(x) + 1) / n * 100, raw=True)
