@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def bop(df, open, high, low, close, col):
+def bop(df, open="open", high="high", low="low", close="close", col="bop"):
     """
     Balance of Power (BOP) is used in technical analysis to evaluate the
     strength of buyers and sellers by assessing the ability to push price to
