@@ -1,5 +1,5 @@
 import pandas as pd
-def donchian_channel(df, high, low, col, n):
+def donchian_channel(df, high="high", low="low", col="dc", n):
     """Calculate donchian channel of given pandas data frame.
     :param df: pandas.DataFrame
     :param n:
